@@ -6,9 +6,9 @@ use strict qw(subs vars refs);				# Make sure we can't mess up
 use warnings FATAL => 'all';				# Enable warnings to catch errors
 
 # Initialize our version
-# $Revision: 1168 $
+# $Revision: 1223 $
 use vars qw( $VERSION );
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 # Import the SSL death routines
 use Net::SSLeay qw( die_now die_if_ssl_error );
@@ -163,7 +163,7 @@ sub _get_self {
 __END__
 =head1 NAME
 
-POE::Component::SSLify::ServerHandle
+POE::Component::SSLify::ServerHandle - server object for POE::Component::SSLify
 
 =head1 ABSTRACT
 
